@@ -1,4 +1,5 @@
 #' Performs Cox Proportional Hazards regression using the omnibus function
+#'
 #' \code{RunCoxRegression_Omnibus} uses user provided data, time/event columns,
 #'       vectors specifying the model, and options to control the convergence
 #'       and starting positions. Has additional options for starting with several
@@ -9,11 +10,12 @@
 #'
 #' @return returns a list of the final results
 #' @export
+#' @family Cox Wrapper Functions
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -48,19 +50,21 @@
 #'                               model_control=list("single"=FALSE,
 #'                               "basic"=FALSE, "CR"=FALSE, 'null'=FALSE))
 #' @importFrom rlang .data
-RunCoxRegression_Omnibus <- function(df, time1="start", time2="end", event0="event", names=c("CONST"), Term_n=c(0), tform="loglin", keep_constant=c(0), a_n=c(0), modelform="M", fir=0, der_iden=0, control=list(),Strat_Col="null", cens_weight=c(1), model_control=list()){
+RunCoxRegression_Omnibus <- function(df, time1="start", time2="end", event0="event", names=c("CONST"), Term_n=c(0), tform="loglin", keep_constant=c(0), a_n=c(0), modelform="M", fir=0, der_iden=0, control=list(),Strat_Col="null", cens_weight=c(1), model_control=list(),Cons_Mat=as.matrix(c(0)),Cons_Vec=c(0)){
+    control <- Def_Control(control)
     val <- Correct_Formula_Order(Term_n, tform, keep_constant, a_n,
-                                 names, der_iden)
+                                 names, der_iden, Cons_Mat, Cons_Vec,control$verbose)
     Term_n <- val$Term_n
     tform <- val$tform
     keep_constant <- val$keep_constant
     a_n <- val$a_n
     der_iden <- val$der_iden
     names <- val$names
+    Cons_Mat <- as.matrix(val$Cons_Mat)
+    Cons_Vec <- val$Cons_Vec
     if (typeof(a_n)!="list"){
         a_n <- list(a_n)
     }
-    control <- Def_Control(control)
     if (control$verbose){
         if (any(val$Permutation != seq_along(tform))){
             message("Warning: model covariate order changed")
@@ -82,7 +86,7 @@ RunCoxRegression_Omnibus <- function(df, time1="start", time2="end", event0="eve
         }
     }
     if (model_control$strata==FALSE){
-        setkeyv(df, c(time2, event0))
+        data.table::setkeyv(df, c(time2, event0))
         uniq <- c(0)
         ce <- c(time1,time2,event0)
     } else {
@@ -108,7 +112,7 @@ RunCoxRegression_Omnibus <- function(df, time1="start", time2="end", event0="eve
             message(paste("Note:",length(uniq)," strata used",sep=" "))
         }
         #
-        setkeyv(df, c(time2, event0, Strat_Col))
+        data.table::setkeyv(df, c(time2, event0, Strat_Col))
         ce <- c(time1,time2,event0,Strat_Col)
     }
     dfend <- df[get(event0)==1, ]
@@ -141,19 +145,69 @@ RunCoxRegression_Omnibus <- function(df, time1="start", time2="end", event0="eve
         a_ns <- c(a_ns, i)
     }
     #
+    if ("maxiters" %in% names(control)){
+    	if (length(control$maxiters) == length(a_n)+1){
+    		#all good, it matches
+    	} else {
+    		if (control$verbose){
+                message(paste("Note: Initial starts:",length(a_n),
+                      ", Number of iterations provided:",length(control$maxiters),". Colossus requires one more iteration counts than number of guesses (for best guess)",sep=" "))
+            }
+            if (length(control$maxiters) < length(a_n)+1){
+		        additional <- length(a_n)+1 - length(control$maxiters)
+		        control$maxiters <- c(control$maxiters, rep(1, additional))
+	        } else {
+	        	additional <- length(a_n)+1
+	        	control$maxiters <- control$maxiters[1:additional]
+	        }
+    	}
+	    if ("guesses" %in% names(control)){
+	        #both are in
+	        if (control$guesses+1 == length(control$maxiters)){
+	            #all good, it matches
+	        } else {
+	            if (control$verbose){
+                    message(paste("Error: guesses:",control["guesses"],
+                          ", iterations per guess:",control["maxiters"],sep=" "))
+                }
+                stop()
+	        }
+	    } else {
+	        control$guesses = length(control$maxiters)-1
+	    }
+	} else {
+	    if ("guesses" %in% names(control)){
+	    	if (control$guesses == length(a_n)){
+	    		#both match, all good
+    		} else {
+    			control$guesses = length(a_n)
+    		}
+            control$maxiters = rep(1,control$guesses+1)
+        } else {
+            control$guesses = length(a_n)
+            control$maxiters = c(rep(1,length(a_n)),control$maxiter)
+        }
+    }
     if (model_control$null){
         a_ns <- matrix(a_ns)
     } else {
         a_ns <- matrix(a_ns,nrow=length(control$maxiters)-1,byrow=TRUE)
     }
+    #
     e <- cox_ph_Omnibus_transition(Term_n,tform,a_ns,dfc,x_all, fir,der_iden,
          modelform, control, as.matrix(df[,ce, with = FALSE]),tu,
-         keep_constant,term_tot, uniq, cens_weight, model_control)
+         keep_constant,term_tot, uniq, cens_weight, model_control,
+         Cons_Mat, Cons_Vec)
+	if (is.nan(e$LogLik)){
+		if (control$verbose){message("Invalid risk")}
+		stop()
+	}
     e$Parameter_Lists$names <- names
     return (e)
 }
 
 #' Performs basic Cox Proportional Hazards regression without special options
+#'
 #' \code{RunCoxRegression} uses user provided data, time/event columns,
 #' vectors specifying the model, and options to control the convergence
 #' and starting position
@@ -162,12 +216,12 @@ RunCoxRegression_Omnibus <- function(df, time1="start", time2="end", event0="eve
 #'
 #' @return returns a list of the final results
 #' @export
-#'
+#' @family Cox Wrapper Functions
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -210,18 +264,127 @@ RunCoxRegression <- function(df, time1, time2, event0, names, Term_n, tform, kee
     return (e)
 }
 
-#' Performs basic Cox Proportional Hazards calculation with no derivative
-#' \code{RunCoxRegression_Single} uses user provided data, time/event columns, vectors specifying the model, and options and returns the log-likelihood
+#' Approximates how many events were due to baseline vs excess risk
+#'
+#' \code{RunCoxEventAssignment} uses user provided data, time/event columns,
+#' vectors specifying the model, and options to control the convergence
+#' and starting position, calculates approximated background and excess events
 #'
 #' @inheritParams R_template
 #'
 #' @return returns a list of the final results
 #' @export
+#' @family Cox Wrapper Functions
+#' @examples
+#' library(data.table)
+#' ## basic example code reproduced from the starting-description vignette
+#' 
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
+#'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
+#'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
+#'                       "a"=c(0,   1,   1,   0,   1,   0,   1),
+#'                       "b"=c(1,   1.1, 2.1, 2,   0.1, 1,   0.2),
+#'                       "c"=c(10,  11,  10,  11,  12,  9,   11),
+#'                       "d"=c(0,   0,   0,   1,   1,   1,   1))
+#' # For the interval case
+#' time1 <- "Starting_Age"
+#' time2 <- "Ending_Age"
+#' event <- "Cancer_Status"
+#' names <- c('a','b','c','d')
+#' Term_n <- c(0,1,1,2)
+#' tform <- c("loglin","lin","lin","plin")
+#' modelform <- "M"
+#' fir <- 0
+#' a_n <- c(0.1, 0.1, 0.1, 0.1)
+#' 
+#' keep_constant <- c(0,0,0,0)
+#' der_iden <- 0
+#' 
+#' control <- list("Ncores"=2,'lr' = 0.75,'maxiter' = 5,'halfmax' = 5,
+#'    'epsilon' = 1e-3,'dbeta_max' = 0.5, 'deriv_epsilon' = 1e-3,
+#'    'abs_max'=1.0,'change_all'=TRUE,'dose_abs_max'=100.0,
+#'    'verbose'=FALSE, 'ties'='breslow','double_step'=1)
+#' 
+#' e <- RunCoxEventAssignment(df, time1, time2, event, names, Term_n, tform,
+#'                      keep_constant, a_n, modelform, fir, der_iden, control)
+#' @importFrom rlang .data
+
+RunCoxEventAssignment <- function(df, time1, time2, event0, names, Term_n, tform, keep_constant, a_n, modelform, fir, der_iden, control){
+    #
+    control <- Def_Control(control)
+    control$maxiters <- c(1, control$maxiter)
+    control$guesses <- 1
+
+    control <- Def_Control(control)
+    val <- Correct_Formula_Order(Term_n, tform, keep_constant, a_n,
+                                 names, der_iden, as.matrix(c(0)), c(0),control$verbose)
+    Term_n <- val$Term_n
+    tform <- val$tform
+    keep_constant <- val$keep_constant
+    a_n <- val$a_n
+    der_iden <- val$der_iden
+    names <- val$names
+    model_control <- Def_model_control(list())
+    val <- Def_modelform_fix(control,model_control,modelform,Term_n)
+    modelform <- val$modelform
+    model_control <- val$model_control
+    if (min(keep_constant)>0){
+        message("Error: Atleast one parameter must be free")
+        stop()
+    }
+    if ("CONST" %in% names){
+        if ("CONST" %in% names(df)){
+            #fine
+        } else {
+            df$CONST <- 1
+        }
+    }
+    data.table::setkeyv(df, c(time2, event0))
+    ce <- c(time1,time2,event0)
+    dfend <- df[get(event0)==1, ]
+    tu <- sort(unlist(unique(dfend[,time2, with = FALSE]),use.names=FALSE))
+    if (length(tu)==0){
+        if (control$verbose){
+            message("Error: no events")
+        }
+        stop()
+    }
+    if (control$verbose){
+        message(paste("Note: ",length(tu)," risk groups",sep=""))
+    }
+    all_names <- unique(names)
+    #
+    df <- Replace_Missing(df,all_names,0.0,control$verbose)
+    #
+    dfc <- match(names,all_names)
+
+    term_tot <- max(Term_n)+1
+    x_all <- as.matrix(df[,all_names, with = FALSE])
+    #
+    #
+    t_check <- Check_Trunc(df,ce)
+    df <- t_check$df
+    ce <- t_check$ce
+    #
+    e <- Assigned_Event_transition(matrix(c(0)),Term_n, tform, a_n, dfc, x_all, fir, der_iden, modelform, control, as.matrix(df[,ce, with = FALSE]), tu, keep_constant, term_tot, model_control)
+    #
+    return (e)
+}
+
+#' Performs basic Cox Proportional Hazards calculation with no derivative
+#'
+#' \code{RunCoxRegression_Single} uses user provided data, time/event columns, vectors specifying the model, and options and returns the log-likelihood
+#'
+#' @inheritParams R_template
+#' @family Cox Wrapper Functions
+#' @return returns a list of the final results
+#' @export
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -261,17 +424,18 @@ RunCoxRegression_Single <- function(df, time1, time2, event0, names, Term_n, tfo
 }
 
 #' Performs basic Cox Proportional Hazards regression with a multiplicative log-linear model
+#'
 #' \code{RunCoxRegression_Basic} uses user provided data, time/event columns, vectors specifying the model, and options to control the convergence and starting positions
 #'
 #' @inheritParams R_template
-#'
+#' @family Cox Wrapper Functions
 #' @return returns a list of the final results
 #' @export
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -312,19 +476,20 @@ RunCoxRegression_Basic <- function(df, time1, time2, event0, names, keep_constan
 
 
 #' Performs basic Cox Proportional Hazards regression with strata effect
+#'
 #' \code{RunCoxRegression_STRATA} uses user provided data,
 #' time/event columns, vectors specifying the model, and options to control
 #' the convergence and starting positions
 #'
 #' @inheritParams R_template
-#'
+#' @family Cox Wrapper Functions
 #' @return returns a list of the final results
 #' @export
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -370,18 +535,19 @@ RunCoxRegression_STRATA <- function(df, time1, time2, event0,  names, Term_n, tf
 
 
 #' Calculates hazard ratios for a reference vector
+#'
 #' \code{RunCoxRegression} uses user provided data,  vectors specifying the model,
 #' and options to calculate relative risk for every row in the provided data
 #'
 #' @inheritParams R_template
-#'
+#' @family Plotting Wrapper Functions
 #' @return returns a list of the final results
 #' @export
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -451,18 +617,19 @@ Cox_Relative_Risk <- function(df, time1, time2, event0,  names, Term_n, tform, k
 }
 
 #' Performs basic Cox Proportional Hazards regression with the null model
+#'
 #' \code{RunCoxRegression} uses user provided data and time/event columns
 #' to calculate the log-likelihood with constant hazard ratio
 #'
 #' @inheritParams R_template
-#'
+#' @family Cox Wrapper Functions
 #' @return returns a list of the final results
 #' @export
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0))
@@ -488,6 +655,7 @@ RunCoxNull <- function(df, time1, time2, event0,control){
 
 
 #' Performs Cox Proportional Hazard model plots
+#'
 #' \code{RunCoxPlots} uses user provided data, time/event columns,
 #' vectors specifying the model, and options to choose and save plots
 #'
@@ -495,11 +663,12 @@ RunCoxNull <- function(df, time1, time2, event0,control){
 #'
 #' @return saves the plots in the current directory and returns a string
 #' @export
+#' @family Plotting Wrapper Functions
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -549,7 +718,7 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
             df$CONST <- 1
         }
     }
-    setkeyv(df, c(time2, event0))
+    data.table::setkeyv(df, c(time2, event0))
     base  <- NULL
     der_iden <- 0
     Plot_Type <- plot_options$type
@@ -648,7 +817,7 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
     val <- Def_modelform_fix(control,model_control,modelform,Term_n)
     modelform <- val$modelform
     model_control <- val$model_control
-    if (Plot_Type[1]=="SURV"){
+    if (tolower(Plot_Type[1])=="surv"){
         if ("time_lims" %in% names(plot_options)){
             #fine
         } else {
@@ -663,9 +832,9 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
         }
     }
     control <- Def_Control(control)
-    verbose <- copy(plot_options$verbose)
-    verbosec <- copy(control$verbose)
-    maxiterc <- copy(control$maxiter)
+    verbose <- data.table::copy(plot_options$verbose)
+    verbosec <- data.table::copy(control$verbose)
+    maxiterc <- data.table::copy(control$maxiter)
     dfend <- df[get(event0)==1, ]
     tu <- sort(unlist(unique(dfend[,time2, with = FALSE]), use.names=FALSE))
     if (length(tu)==0){
@@ -704,52 +873,62 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
     er <- e$Standard_Deviation
     #
     #
-    if (Plot_Type[1]=="SURV"){
+    if (tolower(Plot_Type[1])=="surv"){
         if (verbose){
             message("Note: starting ph_plot")
         }
         #
-        model_control$Surv <- TRUE
-        e <- Plot_Omnibus_transition(Term_n, tform, a_n, dfc, x_all, fir,
-                                     der_iden, modelform, control,
-                                     as.matrix(df[,ce, with = FALSE]),tu,
-                                     keep_constant, term_tot, c(0), c(0),
-                                     model_control)
-        #
-        t <- c()
-        h <- c()
-        ch <- c()
-        surv <- c()
-        if (verbose){
-            message("Note: writing survival data")
-        }
-        dft <- data.table("time"=tu,"base"=e$baseline,
-                          "basehaz"=e$standard_error)
-        for (i in tu){
-            t <- c(t,i)
-            temp <- sum(dft[time<i, base])
-            ch <- c(ch, temp)
-            if (length(h)==0){
-                h <- c(temp)
-            } else {
-                h <- c(h, ch[length(ch)]-ch[length(ch)-1])
+        if (plot_options$strat_haz==FALSE){
+        	if (verbose){
+		        message("Note: nonStratified survival curve calculation")
+		    }
+		    model_control$Surv <- TRUE
+		    e <- Plot_Omnibus_transition(Term_n, tform, a_n, dfc, x_all, fir,
+		                                 der_iden, modelform, control,
+		                                 as.matrix(df[,ce, with = FALSE]),tu,
+		                                 keep_constant, term_tot, c(0), c(0),
+		                                 model_control)
+		    #
+		    t <- c()
+		    h <- c()
+		    ch <- c()
+		    surv <- c()
+		    if (verbose){
+		        message("Note: writing survival data")
+		    }
+		    dft <- data.table::data.table("time"=tu,"base"=e$baseline,
+		                      "basehaz"=e$standard_error)
+		    for (i in tu){
+		        t <- c(t,i)
+		        temp <- sum(dft[time<i, base])
+		        ch <- c(ch, temp)
+		        if (length(h)==0){
+		            h <- c(temp)
+		        } else {
+		            h <- c(h, ch[length(ch)]-ch[length(ch)-1])
+		        }
+		        surv <- c(surv, exp(-1*temp))
+		    }
+		    #
+		    age_unit <- plot_options$age_unit
+		    if (plot_options$Martingale==TRUE){
+		        #
+		        CoxMartingale(verbose, df, time1, time2, event0, e, t, ch,
+		                      plot_options$cov_cols,
+		                      Plot_Type[2], age_unit,plot_options$studyID)
+		        #
+		    }
+		    if (plot_options$surv_curv==TRUE){
+		        CoxSurvival(t,h,ch,surv,Plot_Type[2],verbose,
+		                    plot_options$time_lims, age_unit)
             }
-            surv <- c(surv, exp(-1*temp))
-        }
-        #
-        age_unit <- plot_options$age_unit
-        if (plot_options$Martingale==TRUE){
-            #
-            CoxMartingale(verbose, df, time1, time2, event0, e, t, ch,
-                          plot_options$cov_cols,
-                          Plot_Type[2], age_unit,plot_options$studyID)
-            #
-        }
-        if (plot_options$surv_curv==TRUE){
-            CoxSurvival(t,h,ch,surv,Plot_Type[2],verbose,
-                        plot_options$time_lims, age_unit)
-            if (plot_options$strat_haz==TRUE){
-                model_control$strata <- FALSE
+        } else {
+        	age_unit <- plot_options$age_unit
+        	if (verbose){
+		        message("Note: Stratified survival curve calculation")
+		    }
+            if (plot_options$surv_curv==TRUE){
+                model_control$strata <- TRUE
                 CoxStratifiedSurvival(verbose, df, event0, time1, time2,
                      all_names,Term_n, tform, a_n, er, fir, der_iden,
                      modelform, control, keep_constant, Plot_Type,
@@ -763,11 +942,11 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
                            tform, a_n, er, fir, der_iden, modelform,
                            control,keep_constant, Plot_Type,age_unit)
         }
-    } else if (Plot_Type[1]=="RISK"){
+    } else if (tolower(Plot_Type[1])=="risk"){
         CoxRisk(verbose, df, event0, time1, time2, names,Term_n, tform,
                 a_n, fir, der_iden, modelform, control,keep_constant,
                 Plot_Type, b, er)
-    } else if (Plot_Type[1]=="SCHOENFELD"){
+    } else if (tolower(Plot_Type[1])=="schoenfeld"){
         age_unit <- plot_options$age_unit
         PlotCox_Schoenfeld_Residual(df, time1, time2, event0, names, Term_n,
                                     tform, keep_constant, a_n, modelform, fir,
@@ -778,6 +957,7 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
 
 #' Performs basic cox regression, with multiple guesses, starts with
 #' solving for a single term
+#'
 #' \code{RunCoxRegression_Tier_Guesses} uses user provided data, time/event
 #' columns, vectors specifying the model, and options to control the
 #' convergence and starting positions, with additional guesses
@@ -786,13 +966,12 @@ RunCoxPlots <- function(df, time1, time2, event0, names, Term_n, tform, keep_con
 #'
 #' @return returns a list of the final results
 #' @export
-#'
-#' @export
+#' @family Cox Wrapper Functions
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -909,18 +1088,19 @@ RunCoxRegression_Tier_Guesses <- function(df, time1, time2, event0, names, Term_
 
 
 #' Performs basic Cox Proportional Hazards regression with competing risks
+#'
 #' \code{RunCoxRegression_CR} uses user provided data, time/event columns, vectors specifying the model, and options to control the convergence, starting positions, and censoring adjustment
 #'
 #' @inheritParams R_template
 #'
 #' @return returns a list of the final results
 #' @export
-#'
+#' @family Cox Wrapper Functions
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   2,   1,   2,   0),
@@ -966,17 +1146,19 @@ RunCoxRegression_CR <- function(df, time1, time2, event0, names, Term_n, tform,
 }
 
 #' Performs basic Cox Proportional Hazards regression, Allows for multiple starting guesses on c++ side
+#'
 #' \code{RunCoxRegression_Guesses_CPP} uses user provided data, time/event columns, vectors specifying the model, and options to control the convergence and starting positions. Has additional options to starting with several initial guesses
 #'
 #' @inheritParams R_template
 #'
 #' @return returns a list of the final results
 #' @export
+#' @family Cox Wrapper Functions
 #' @examples
 #' library(data.table)
 #' ## basic example code reproduced from the starting-description vignette
 #' 
-#' df <- data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
+#' df <- data.table::data.table("UserID"=c(112, 114, 213, 214, 115, 116, 117),
 #'            "Starting_Age"=c(18,  20,  18,  19,  21,  20,  18),
 #'              "Ending_Age"=c(30,  45,  57,  47,  36,  60,  55),
 #'           "Cancer_Status"=c(0,   0,   1,   0,   1,   0,   0),
@@ -1050,7 +1232,7 @@ RunCoxRegression_Guesses_CPP <- function(df, time1, time2, event0, names, Term_n
         a_n_default[i] <- a_n[[1]][i]
     }
     if (guesses_control$strata==FALSE){
-        setkeyv(df, c(time2, event0))
+        data.table::setkeyv(df, c(time2, event0))
         dfend <- df[get(event0)==1, ]
         tu <- sort(unlist(unique(dfend[,time2, with = FALSE]),use.names=FALSE))
         if (length(tu)==0){
@@ -1072,16 +1254,6 @@ RunCoxRegression_Guesses_CPP <- function(df, time1, time2, event0, names, Term_n
         x_all <- as.matrix(df[,all_names, with = FALSE])
         ce <- c(time1,time2,event0)
         #
-        t_check <- Check_Trunc(df,ce)
-        df <- t_check$df
-        ce <- t_check$ce
-        #
-        #
-        dat_val <- Gather_Guesses_CPP(df, dfc, names, Term_n, tform, keep_constant,
-                                      a_n, x_all, a_n_default, modelform, fir, control,
-                                      guesses_control, model_control)
-        a_ns <- dat_val$a_ns
-        maxiters <- dat_val$maxiters
     } else {
         #
         dfend <- df[get(event0)==1, ]
@@ -1102,7 +1274,7 @@ RunCoxRegression_Guesses_CPP <- function(df, time1, time2, event0, names, Term_n
             message(paste("Note:",length(uniq)," strata used",sep=" "))
         }
         #
-        setkeyv(df, c(time2, event0, Strat_Col))
+        data.table::setkeyv(df, c(time2, event0, Strat_Col))
         dfend <- df[get(event0)==1, ]
         tu <- sort(unlist(unique(dfend[,time2, with = FALSE]),use.names=FALSE))
         if (length(tu)==0){
@@ -1124,17 +1296,16 @@ RunCoxRegression_Guesses_CPP <- function(df, time1, time2, event0, names, Term_n
         x_all <- as.matrix(df[,all_names, with = FALSE])
         ce <- c(time1,time2,event0,Strat_Col)
         #
-        #
-        t_check <- Check_Trunc(df,ce)
-        df <- t_check$df
-        ce <- t_check$ce
-        #
-        dat_val <- Gather_Guesses_CPP(df, dfc, names, Term_n, tform, keep_constant,
-                                      a_n, x_all, a_n_default, modelform, fir, control,
-                                      guesses_control, model_control)
-        a_ns <- dat_val$a_ns
-        maxiters <- dat_val$maxiters
     }
+    t_check <- Check_Trunc(df,ce)
+    df <- t_check$df
+    ce <- t_check$ce
+    #
+    dat_val <- Gather_Guesses_CPP(df, dfc, names, Term_n, tform, keep_constant,
+                                  a_n, x_all, a_n_default, modelform, fir, control,
+                                  guesses_control, model_control)
+    a_ns <- dat_val$a_ns
+    maxiters <- dat_val$maxiters
     #
     control$maxiters <- c(maxiters,control$maxiter)
     control$guesses <- length(maxiters)
